==> phplist-2.10.5p0.tgz: lists/admin/info/es/vote.php <==


<p><b>Vote por PHPlist</b><br/>
Si piensa que PHPlist es estupendo, y recomendar&iacute;a su uso,
&#191;porqu&eacute; no vota en algunos sitios web?
</p>
<p>Si encontr&oacute; PHPlist en un sitio diferente y cree que ese
sitio se debe de incluir aqu&iacute; <a
href="mailto:phplist2@tincan.co.uk?subject=New
Directory">env&iacute;enos una nota</a></p>
<ul>
<li><b>En freshmeat</b>
<form method="post" action="http://freshmeat.net/rate/store/" target="_vote">
  <input type="hidden" name="project_id" value="7994">
<table cellspacing="3" cellpadding="0" border="0">
  <tr>
    <td valign="middle" width="15%">
  <b>Puntuaci&oacute;n:</b>
    </td>
  <td valign="top" width="85%">
  <select name="rating" onchange="submit()">

  <option value="">-
      <option value="1">1</option>
      <option value="2">2</option>
      <option value="3">3</option>
      <option value="4">4</option>
      <option value="5">5</option>
      <option value="6">6</option>

      <option value="7">7</option>
      <option value="8">8</option>
      <option value="9">9</option>
      <option value="10" selected>10</option>
    </select>
  <input type="submit" value="vote">
    </td>
  </tr>
</table>
</form>
</li>
<li><b>En codetransit</b>
<form action="http://www.codetransit.com/index.php" method=post name=rate531 target="_vote"><input type=hidden name=action value=rate><input type=hidden name=id value=531>
          <select name=score size=1 style="font-family: Verdana, Tahoma, Arial, Helvetica; font-size: 10pt; color: #000000" onchange="document.rate531.submit()">
            <option>Escoja
            <option value="1">Malo
            <option value="2">Regular
            <option value="3">Bueno
            <option value="4">Muy Bueno
            <option value="5" selected>Excelente
          </select>
  <input type="submit" value="vote">
          </form> o escriba una <a href="http://www.codetransit.com/comments/index.php?action=addcommentsform&id=531&title=PHPlist&version=1.8.0" target="_review">Rese&ntilde;a</a>
<br/><br/></li>
<li><b>En PHPWelt</b> (alem&aacute;n)
<form action="http://www.phpwelt.de/archiv/arcscript.php" method="post" target="_vote">
<select name="arcwert" class="vote">
<option selected>10
<option>9
<option>8
<option>7
<option>6
<option>5
<option>4
<option>3
<option>2
<option>1
</select>
<input type="submit" value="vote">
<input type="hidden" name="ack_vote" value="TRUE">
<input type="hidden" name="arcid" value="226">
</form>
</li>
<li><b>En scripts.org</b> (alem&aacute;n)<br/>
<a href="http://www.scripts.org/links.php?op=rate&lid=773&progname=PHPlist" target="_vote">Eval&uacute;e PHPlist</a><br/><br/>
</li>
<li><b>En resourceindex</b><br/>
<a href="http://php.resourceindex.com/detail/00074.html" target="_vote">Eval&uacute;e PHPlist</a><br/><br/>
</li>
<li><b>En <a href="http://www.hotscripts.com/?RID=9619">Hotscripts</a></b><br/>
<form action="http://www.hotscripts.com/cgi-bin/rate.cgi" method="POST">
<input type=hidden name="ID" value="5015">
<table BORDER="0" CELLSPACING="0" CELLPADDING="2" bgcolor="#CCCC99">
<tr><td><font face="arial,verdana,helvetica" size="2"><b>Cabina de
      voto para visitantes: </b></td>
<td><select name="rate" size="1"><option selected>Escoja su evaluaci&oacute;n</option>
<option value="5" selected>&#161;Excelente!</option><option
      value="4">Muy bueno</option>
<option value="3">Bueno</option><option value="2">Regular</option>
<option value="1">Malo</option></select></td><td>
<input type="submit" value="&#161;Vote!"></td></tr></table></form>
<a
      href="http://www.hotscripts.com/review/?linkid=5015&returnto=http://www.hotscripts.com/Detailed/5015.html"
      target="_review">Escriba una rese&ntilde;a</a><br/><br/>

</li>
<li><b>En Devscripts.com</b>
<form action="http://devscripts.com/vote.php" method="post" name="frmRate" target="_vote">
<input type="hidden" name="strScriptId" value="1465">
    <select name="strRValue" onChange="document.frmRate.submit();">
        <option value="NULL">Evaluaci&oacute;n</option>
        <option value="10" selected>10</option>

        <option value="9">9</option>
        <option value="8">8</option>
        <option value="7">7</option>
        <option value="6">6</option>
        <option value="5">5</option>
        <option value="4">4</option>

        <option value="3">3</option>
        <option value="2">2</option>
        <option value="1">1</option>
    </select><input type="submit" value="vote">
</form>
<a href="http://devscripts.com/review.php?sId=1465"
        target="_review">Escriba una rese&ntilde;a</a><br/><br/>
</li>
<li><b>En webscript.ru</b> (ruso)<br/>
<form name="rate" method="post" action="http://webscript.ru/action.php?sid=598201422&action=rate&linkid=22&having=753">
5 <input type="radio" value="5" name="form_rate_radio_vote" checked>
4  <input type="radio" value="4" name="form_rate_radio_vote">
3 <input type="radio" value="3" name="form_rate_radio_vote">
2 <input type="radio" value="2" name="form_rate_radio_vote">
1 <input type="radio" value="1" name="form_rate_radio_vote">
<input type="submit" name="form_rate_button_rate" class="button" value="Vote">
</form>
</li>
<li><b>En PHPindex.com</b> (franc&eacute;s)<br/>
<a
        href="http://www.phpindex.com/annuaire/annuaire_critique.php3?annuaire_critique_annuaire_id=917">Escriba
        una rese&ntilde;a</a><br/><br/>
</li>
<li><b>En bigboys</b><br/>
<form method="GET" action="http://www.big-boys.com/php/vote1.asp">
    <select size="1" name="F1">
      <option VALUE="1">1 - Malo
      <option VALUE="2">2
      <option VALUE="3">3
      <option VALUE="4">4
      <option VALUE="5">5 - Regular
      <option VALUE="6">6
      <option VALUE="7">7
      <option VALUE="8">8
      <option VALUE="9">9
      <option VALUE="10" selected>10 - Excelente
      <input Type="Hidden" Name="ID" Value="151">
    </select>
    <input type="submit" value="Vote">
</form>

==> phplist-2.10.17p2.tgz: lists/admin/info/es/vote.php <==


<p><b>Vote por PHPlist</b><br/>
Si piensa que PHPlist es estupendo, y recomendar&iacute;a su uso,
&#191;porqu&eacute; no vota en algunos sitios web?
</p>
<p>Si encontr&oacute; PHPlist en un sitio diferente y cree que ese
sitio se debe de incluir aqu&iacute; <a
href="mailto:phplist2@tincan.co.uk?subject=New
Directory">env&iacute;enos una nota</a></p>
<ul>
<li><b>En freshmeat</b>
<form method="post" action="http://freshmeat.net/rate/store/" target="_vote">
  <input type="hidden" name="project_id" value="7994">
<table cellspacing="3" cellpadding="0" border="0">
  <tr>
    <td valign="middle" width="15%">
  <b>Puntuaci&oacute;n:</b>
    </td>
  <td valign="top" width="85%">
  <select name="rating" onchange="submit()">

  <option value="">-
      <option value="1">1</option>
      <option value="2">2</option>
      <option value="3">3</option>
      <option value="4">4</option>
      <option value="5">5</option>
      <option value="6">6</option>

      <option value="7">7</option>
      <option value="8">8</option>
      <option value="9">9</option>
      <option value="10" selected>10</option>
    </select>
  <input type="submit" value="vote">
    </td>
  </tr>
</table>
</form>
</li>
<li><b>En codetransit</b>
<form action="http://www.codetransit.com/index.php" method=post name=rate531 target="_vote"><input type=hidden name=action value=rate><input type=hidden name=id value=531>
          <select name=score size=1 style="font-family: Verdana, Tahoma, Arial, Helvetica; font-size: 10pt; color: #000000" onchange="document.rate531.submit()">
            <option>Escoja
            <option value="1">Malo
            <option value="2">Regular
            <option value="3">Bueno
            <option value="4">Muy Bueno
            <option value="5" selected>Excelente
          </select>
  <input type="submit" value="vote">
          </form> o escriba una <a href="http://www.codetransit.com/comments/index.php?action=addcommentsform&id=531&title=PHPlist&version=1.8.0" target="_review">Rese&ntilde;a</a>
<br/><br/></li>
<li><b>En PHPWelt</b> (alem&aacute;n)
<form action="http://www.phpwelt.de/archiv/arcscript.php" method="post" target="_vote">
<select name="arcwert" class="vote">
<option selected>10
<option>9
<option>8
<option>7
<option>6
<option>5
<option>4
<option>3
<option>2
<option>1
</select>
<input type="submit" value="vote">
<input type="hidden" name="ack_vote" value="TRUE">
<input type="hidden" name="arcid" value="226">
</form>
</li>
<li><b>En scripts.org</b> (alem&aacute;n)<br/>
<a href="http://www.scripts.org/links.php?op=rate&lid=773&progname=PHPlist" target="_vote">Eval&uacute;e PHPlist</a><br/><br/>
</li>
<li><b>En resourceindex</b><br/>
<a href="http://php.resourceindex.com/detail/00074.html" target="_vote">Eval&uacute;e PHPlist</a><br/><br/>
</li>
<li><b>En <a href="http://www.hotscripts.com/?RID=9619">Hotscripts</a></b><br/>
<form action="http://www.hotscripts.com/cgi-bin/rate.cgi" method="POST">
<input type=hidden name="ID" value="5015">
<table BORDER="0" CELLSPACING="0" CELLPADDING="2" bgcolor="#CCCC99">
<tr><td><span class="highlight"><b>Cabina de
      voto para visitantes: </b></span></td>
<td><select name="rate" size="1"><option selected>Escoja su evaluaci&oacute;n</option>
<option value="5" selected>&#161;Excelente!</option><option
      value="4">Muy bueno</option>
<option value="3">Bueno</option><option value="2">Regular</option>
<option value="1">Malo</option></select></td><td>
<input type="submit" value="&#161;Vote!"></td></tr></table></form>
<a
      href="http://www.hotscripts.com/review/?linkid=5015&returnto=http://www.hotscripts.com/Detailed/5015.html"
      target="_review">Escriba una rese&ntilde;a</a><br/><br/>

</li>
<li><b>En Devscripts.com</b>
<form action="http://devscripts.com/vote.php" method="post" name="frmRate" target="_vote">
<input type="hidden" name="strScriptId" value="1465">
    <select name="strRValue" onChange="document.frmRate.submit();">
        <option value="NULL">Evaluaci&oacute;n</option>
        <option value="10" selected>10</option>

        <option value="9">9</option>
        <option value="8">8</option>
        <option value="7">7</option>
        <option value="6">6</option>
        <option value="5">5</option>
        <option value="4">4</option>

        <option value="3">3</option>
        <option value="2">2</option>
        <option value="1">1</option>
    </select><input type="submit" value="vote">
</form>
<a href="http://devscripts.com/review.php?sId=1465"
        target="_review">Escriba una rese&ntilde;a</a><br/><br/>
</li>
<li><b>En webscript.ru</b> (ruso)<br/>
<form name="rate" method="post" action="http://webscript.ru/action.php?sid=598201422&action=rate&linkid=22&having=753">
5 <input type="radio" value="5" name="form_rate_radio_vote" checked>
4  <input type="radio" value="4" name="form_rate_radio_vote">
3 <input type="radio" value="3" name="form_rate_radio_vote">
2 <input type="radio" value="2" name="form_rate_radio_vote">
1 <input type="radio" value="1" name="form_rate_radio_vote">
<input type="submit" name="form_rate_button_rate" class="button" value="Vote">
</form>
</li>
<li><b>En PHPindex.com</b> (franc&eacute;s)<br/>
<a
        href="http://www.phpindex.com/annuaire/annuaire_critique.php3?annuaire_critique_annuaire_id=917">Escriba
        una rese&ntilde;a</a><br/><br/>
</li>
<li><b>En bigboys</b><br/>
<form method="GET" action="http://www.big-boys.com/php/vote1.asp">
    <select size="1" name="F1">
      <option VALUE="1">1 - Malo
      <option VALUE="2">2
      <option VALUE="3">3
      <option VALUE="4">4
      <option VALUE="5">5 - Regular
      <option VALUE="6">6
      <option VALUE="7">7
      <option VALUE="8">8
      <option VALUE="9">9
      <option VALUE="10" selected>10 - Excelente
      <input Type="Hidden" Name="ID" Value="151">
    </select>
    <input type="submit" value="Vote">
</form>
